@@ -13,7 +13,6 @@ use Data::Dumper;
 use Config;
 use Eixo::Rest::RequestSync;
 
-use Eixo::Rest::Uri;
 
 
 my $REQ_PARSER = qr/\:\:([a-z]+)([A-Z]\w+?)$/;
@@ -104,8 +103,8 @@ sub AUTOLOAD{
 
     my $uri;
 
-    if(my $uri_mask = $args{uri_mask}) {
-        $uri = $self->build_uri_from_mask($uri_mask, \%args);
+    if($uri = $args{uri}) {
+        $uri = $self->build_predefined_uri($uri);
     }
     else{
 	    $uri = $self->build_uri($entity, $id, $action, $args{__implicit_format});
@@ -252,22 +251,16 @@ sub build_uri {
         	URI->new($uri);
 }
 
-sub build_uri_from_mask{
-    my ($self, $uri_mask, $args) = @_;
+sub build_predefined_uri{
+    my ($self, $uri) = @_;
 
     my $endpoint = $self->{endpoint};
     
     $endpoint .= "/" unless($endpoint =~ /\/$/);
 
-    my $uri = $self->{endpoint} . Eixo::Rest::Uri->new(
+    $uri =~ s/^\///;
 
-        args=>$args->{args},
-
-        uri_mask=>$args->{uri_mask}
-
-    )->build;
-
-    return URI->new($uri)
+    return URI->new($endpoint . $uri)
 }
 
 
